(no-trailing-slash-url? s)Returns true if s is a valid absolute URL and does not end with a slash
Returns true if s is a valid absolute URL and does not end with a slash
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |