(clasify-ref-keys refs)Groups a collection of reference keywords into a map of :required-keys and :optional-keys based on their namespace. If a key is marked as both required and optional, requirement takes priority.
Groups a collection of reference keywords into a map of :required-keys and :optional-keys based on their namespace. If a key is marked as both required and optional, requirement takes priority.
(compile {:keys [path method auth? request transformers description]
:as op
:or {auth? true}})Compiles an operation map into an executable closure mapped to the operation's name. The resulting map also exposes the required and optional referent keys needed for execution.
The compiled function expects a runtime context map and a request handler.
Compiles an operation map into an executable closure mapped to the operation's name. The resulting map also exposes the required and optional referent keys needed for execution. The compiled function expects a runtime context map and a request handler.
(flatten-operations operations)Flattens nested operation groups into a single vector with fully resolved paths.
Flattens nested operation groups into a single vector with fully resolved paths.
(full-url ctx path)Constructs a complete URL by resolving the path against the context (ctx) and appending it to the base-url found within the context.
Constructs a complete URL by resolving the path against the context (ctx) and appending it to the base-url found within the context.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |