ehr-adapter.operation


clasify-ref-keysclj

(clasify-ref-keys refs)

Groups a collection of reference keywords into a map of :required-keys and :optional-keys based on their namespace. If a key is marked as both required and optional, requirement takes priority.

Groups a collection of reference keywords into a map of :required-keys 
and :optional-keys based on their namespace. If a key is marked as both 
required and optional, requirement takes priority.
raw docstring

compileclj

(compile {:keys [path method request description] :as op})

Compiles an operation map into an executable closure mapped to the operation's name. The resulting map also exposes the required and optional referent keys needed for execution.

The compiled function expects a runtime context map and a request handler.

Compiles an operation map into an executable closure mapped to the 
operation's name. The resulting map also exposes the required and 
optional referent keys needed for execution.

The compiled function expects a runtime context map and a request handler.
raw docstring

full-urlclj

(full-url ctx path)

Constructs a complete URL by resolving the path against the context (ctx) and appending it to the base-url found within the context.

Constructs a complete URL by resolving the path against the context (ctx) 
and appending it to the base-url found within the context.
raw docstring

path->strclj

(path->str ctx path)

Resolves any dynamic references inside the path vector using the provided context (ctx) and joins the resulting segments into a URL path string.

Resolves any dynamic references inside the path vector using the provided 
context (ctx) and joins the resulting segments into a URL path string.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries